##  Creating Fact Sheets and Relations for Multiple Items
  1. In the inbox, use the checkboxes next to each item to select multiple fact sheets from the list.
  2. Choose Link at the top to create the fact sheets and relations in bulk.
